@@ -63,7 +63,7 @@
 #define KDECORATIONS2_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KDECORATIONS2_NO_DEPRECATED
-#  define KDECORATIONS2_DISABLE_DEPRECATED_BEFORE_AND_AT 0x51703
+#  define KDECORATIONS2_DISABLE_DEPRECATED_BEFORE_AND_AT 0x51a02
 #endif
 #ifdef KDECORATIONS2_NO_DEPRECATED_WARNINGS
 #  define KDECORATIONS2_DEPRECATED_WARNINGS_SINCE 0
@@ -73,7 +73,7 @@
 #  ifdef KDECORATIONS2_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KDECORATIONS2_DEPRECATED_WARNINGS_SINCE KDECORATIONS2_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KDECORATIONS2_DEPRECATED_WARNINGS_SINCE 0x51703
+#    define KDECORATIONS2_DEPRECATED_WARNINGS_SINCE 0x51a02
 #  endif
 #endif
 
@@ -134,7 +134,7 @@
 #define KDECORATIONS2_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KDECORATIONS2_NO_DEPRECATED
-#  define KDECORATIONS2_DISABLE_DEPRECATED_BEFORE_AND_AT 0x51703
+#  define KDECORATIONS2_DISABLE_DEPRECATED_BEFORE_AND_AT 0x51a02
 #endif
 #ifdef KDECORATIONS2_NO_DEPRECATED_WARNINGS
 #  define KDECORATIONS2_DEPRECATED_WARNINGS_SINCE 0
@@ -144,7 +144,7 @@
 #  ifdef KDECORATIONS2_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KDECORATIONS2_DEPRECATED_WARNINGS_SINCE KDECORATIONS2_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KDECORATIONS2_DEPRECATED_WARNINGS_SINCE 0x51703
+#    define KDECORATIONS2_DEPRECATED_WARNINGS_SINCE 0x51a02
 #  endif
 #endif
 
